asr.magstate
============

.. automodule:: asr.magstate

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_magstate
   .. autofunction:: webpanel
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: Result
      :members:
   
   

   
   
   